//
//  PrintGridPageRenderer.m
//  printTest
//
//  Created by yasuda on 11/03/04.
//  Copyright 2011 __MyCompanyName__. All rights reserved.
//

#import "PrintGridPageRenderer.h"


@implementation PrintGridPageRenderer


@synthesize imageToPrint;
@synthesize gridMulti;
@synthesize headerString;

// This code always draws one image at print time.
-(NSInteger)numberOfPages
{
	return 1; // 1 page 限定なのでこう答える
}

// 試しにヘッダに何か書いてみる
-(void)drawHeaderForPageAtIndex:(NSInteger)index inRect:(CGRect)headerRect
{
	UIFont *font = [UIFont fontWithName:HEADER_FONT size:HEADER_FOOTER_TEXT_HEIGHT]; 
    CGFloat startX = headerRect.origin.x + 10;
	CGSize  stringSize = [headerString sizeWithFont:font];
    CGFloat startY = headerRect.origin.y + ( headerRect.size.height - stringSize.height ) / 2 ; 
    CGPoint startPoint = CGPointMake(startX, startY);
    [headerString drawAtPoint:startPoint withFont:font];
}

// コンテント描画
-(void)drawContentForPageAtIndex:(NSInteger)pageIndex inRect:(CGRect)contentRect
{
	if(self.imageToPrint){
		CGSize imageSize = [self.imageToPrint size];
		NSInteger multi=[gridMulti intValue]; // multi x multi に並べる
		CGFloat gap = 5.0; // グリッド間の隙間 

		// 縦横のスケール値を得る
		CGFloat width_scale = ((CGFloat)contentRect.size.width-(gap*(multi-1)))/multi/imageSize.width;
		CGFloat height_scale = ((CGFloat)contentRect.size.height-(gap*(multi-1)))/multi/imageSize.height;
		CGFloat scale = width_scale < height_scale ? width_scale : height_scale; // 小さい方をとる				
		
		CGFloat width=imageSize.width*scale; // 出力するイメージのサイズ
		CGFloat height=imageSize.height*scale;
		
		CGFloat marginWidth = contentRect.origin.x + 
							 (contentRect.size.width - width*multi - gap*(multi-1) ) / 2.0;
		CGFloat marginHeight = contentRect.origin.y + 
							  (contentRect.size.height - height*multi - gap*(multi-1)) / 2.0;

		for(int w=0; w<multi; w++) { 
			for(int h=0; h<multi; h++) { 
				CGRect destRect = CGRectMake(marginWidth + gap * w + width * w,
				      					     marginHeight + gap * h + height * h,
									         width, height); 
				// 描画は対象が UIImage なので便利なメソッドがある
				[self.imageToPrint drawInRect:destRect];				
			}
		}
		
	} else {
		NSLog(@"%s No image to draw!", __func__);
	}
}


@end
